@@ -25,9 +25,9 @@
 
 #include "dmap-mdns-publisher.h"
 
-#define DMAP_MDNS_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), TYPE_DMAP_MDNS_PUBLISHER, DmapMdnsPublisherPrivate))
+#define DMAP_MDNS_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_MDNS_PUBLISHER, DMAPMdnsPublisherPrivate))
 
-struct DmapMdnsPublisherPrivate
+struct DMAPMdnsPublisherPrivate
 {
 	DNSServiceRef	 sdref;
         char            *name;
@@ -41,7 +41,7 @@ enum {
 
 static guint signals [LAST_SIGNAL] = { 0, };
 
-G_DEFINE_TYPE (DmapMdnsPublisher, dmap_mdns_publisher, G_TYPE_OBJECT)
+G_DEFINE_TYPE (DMAPMdnsPublisher, dmap_mdns_publisher, G_TYPE_OBJECT)
 
 static gpointer publisher_object = NULL;
 
@@ -55,7 +55,7 @@ dmap_mdns_publisher_error_quark (void)
 }
 
 gboolean
-dmap_mdns_publisher_rename_at_port (DmapMdnsPublisher *publisher,
+dmap_mdns_publisher_rename_at_port (DMAPMdnsPublisher *publisher,
 				    guint	       port,
                                     const char        *name,
                                     GError           **error)
@@ -66,7 +66,7 @@ dmap_mdns_publisher_rename_at_port (DmapMdnsPublisher *publisher,
 }
 
 gboolean
-dmap_mdns_publisher_publish (DmapMdnsPublisher *publisher,
+dmap_mdns_publisher_publish (DMAPMdnsPublisher *publisher,
                              const char          *name,
                              guint                port,
                              const char          *type_of_service,
@@ -110,7 +110,7 @@ dmap_mdns_publisher_publish (DmapMdnsPublisher *publisher,
 }
 
 gboolean
-dmap_mdns_publisher_withdraw (DmapMdnsPublisher *publisher,
+dmap_mdns_publisher_withdraw (DMAPMdnsPublisher *publisher,
 			      guint port,
                               GError             **error)
 {
@@ -148,7 +148,7 @@ dmap_mdns_publisher_get_property (GObject        *object,
 static void
 dmap_mdns_publisher_finalize (GObject *object)
 {
-        DmapMdnsPublisher *publisher;
+        DMAPMdnsPublisher *publisher;
 
         g_return_if_fail (object != NULL);
         g_return_if_fail (IS_DMAP_MDNS_PUBLISHER (object));
@@ -163,7 +163,7 @@ dmap_mdns_publisher_finalize (GObject *object)
 }
 
 static void
-dmap_mdns_publisher_class_init (DmapMdnsPublisherClass *klass)
+dmap_mdns_publisher_class_init (DMAPMdnsPublisherClass *klass)
 {
         GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
@@ -175,7 +175,7 @@ dmap_mdns_publisher_class_init (DmapMdnsPublisherClass *klass)
                 g_signal_new ("published",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (DmapMdnsPublisherClass, published),
+			      G_STRUCT_OFFSET (DMAPMdnsPublisherClass, published),
                               NULL,
                               NULL,
                               g_cclosure_marshal_VOID__STRING,
@@ -185,29 +185,29 @@ dmap_mdns_publisher_class_init (DmapMdnsPublisherClass *klass)
                 g_signal_new ("name-collision",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (DmapMdnsPublisherClass, name_collision),
+			      G_STRUCT_OFFSET (DMAPMdnsPublisherClass, name_collision),
                               NULL,
                               NULL,
                               g_cclosure_marshal_VOID__STRING,
                               G_TYPE_NONE,
                               1, G_TYPE_STRING);
 
-        g_type_class_add_private (klass, sizeof (DmapMdnsPublisherPrivate));
+        g_type_class_add_private (klass, sizeof (DMAPMdnsPublisherPrivate));
 }
 
 static void
-dmap_mdns_publisher_init (DmapMdnsPublisher *publisher)
+dmap_mdns_publisher_init (DMAPMdnsPublisher *publisher)
 {
         publisher->priv = DMAP_MDNS_PUBLISHER_GET_PRIVATE (publisher);
 }
 
-DmapMdnsPublisher *
+DMAPMdnsPublisher *
 dmap_mdns_publisher_new (void)
 {
         if (publisher_object) {
                 g_object_ref (publisher_object);
         } else {
-                publisher_object = g_object_new (TYPE_DMAP_MDNS_PUBLISHER, NULL);
+                publisher_object = g_object_new (DMAP_TYPE_MDNS_PUBLISHER, NULL);
                 g_object_add_weak_pointer (publisher_object,
                                            (gpointer *) &publisher_object);
         }
